Crate bq2515x

Crate bq2515x 

BQ2515x

Rust no-std device driver for the BQ2515x family of Texas Instruments linear battery chargers.

Should also work, but only a subset of registers and features are supported by the devices:

Support

  • All low level registers
  • Easy management of the Low Power (/LP) pin

Not (yet) supported

  • High level basic operation
  • High level ADC comparators

Example

See the examples/ folder in this repository on how to use the library crate.

Modules

hl
High level interface for the Bq2515x family of chips providing convenience methods and a Rust-style interface.
ll
Low level interface for the Bq2515x family of chips providing register access.
prelude
Strongly typed register values used by this crate.